var Vue3Notion=(function(exports,vue,katex,Prism,vue3){'use strict';function _interopDefaultLegacy(e){return e&&typeof e==='object'&&'default'in e?e:{'default':e}}var katex__default=/*#__PURE__*/_interopDefaultLegacy(katex);var Prism__default=/*#__PURE__*/_interopDefaultLegacy(Prism);// utils from react-notion
const getTextContent = (text) => {
    return text.reduce((prev, current) => prev + current[0], "");
};
const groupBlockContent = (blockMap) => {
    const output = [];
    let lastType = undefined;
    let index = -1;
    Object.keys(blockMap).forEach((id) => {
        blockMap[id].value.content?.forEach((blockId) => {
            const blockType = blockMap[blockId]?.value?.type;
            if (blockType && blockType !== lastType) {
                index++;
                lastType = blockType;
                output[index] = [];
            }
            output[index].push(blockId);
        });
        lastType = undefined;
    });
    return output;
};
const getListNumber = (blockId, blockMap) => {
    const groups = groupBlockContent(blockMap);
    const group = groups.find((g) => g.includes(blockId));
    if (!group) {
        return;
    }
    return group.indexOf(blockId) + 1;
};
const defaultMapImageUrl = (image = "", block) => {
    const url = new URL(`https://www.notion.so${image.startsWith("/image") ? image : `/image/${encodeURIComponent(image)}`}`);
    if (block && !image.includes("/images/page-cover/")) {
        const table = block.value.parent_table === "space" ? "block" : block.value.parent_table;
        url.searchParams.set("table", table);
        url.searchParams.set("id", block.value.id);
        url.searchParams.set("cache", "v2");
    }
    return url.toString();
};
const defaultMapPageUrl = (pageId = "") => {
    pageId = pageId.replace(/-/g, "");
    return `/${pageId}`;
};const defineNotionProps = {
    blockMap: { type: Object, required: true },
    contentId: { type: String, required: false },
    contentIndex: { type: Number, default: 0 },
    embedAllow: { type: String, default: "fullscreen" },
    fullPage: { type: Boolean, default: false },
    hideList: { type: Array, default: () => [] },
    level: { type: Number, default: 0 },
    mapImageUrl: { type: Function, default: defaultMapImageUrl },
    mapPageUrl: { type: Function, default: defaultMapPageUrl },
    pageLinkOptions: Object,
    pageLinkTarget: { type: String, default: "_self" },
    prism: { type: Boolean, default: false },
    katex: { type: Boolean, default: false },
    textLinkTarget: { type: String, default: "_blank" },
};
const useNotionBlock = (props) => {
    const block = vue.computed(() => {
        const id = props.contentId || Object.keys(props.blockMap)[0];
        return props.blockMap[id];
    });
    const pass = vue.computed(() => {
        return {
            blockMap: props.blockMap,
            contentId: props.contentId,
            contentIndex: props.contentIndex,
            embedAllow: props.embedAllow,
            fullPage: props.fullPage,
            hideList: props.hideList,
            level: props.level,
            mapImageUrl: props.mapImageUrl,
            mapPageUrl: props.mapPageUrl,
            pageLinkOptions: props.pageLinkOptions,
            prism: props.prism,
            katex: props.katex,
        };
    });
    const f = vue.computed(() => {
        return {
            block_aspect_ratio: block.value?.value?.format?.block_aspect_ratio,
            block_height: block.value?.value?.format?.block_height || 1,
            block_width: block.value?.value?.format?.block_width || 1,
            block_color: block.value?.value?.format?.block_color,
            bookmark_icon: block.value?.value?.format?.bookmark_icon,
            bookmark_cover: block.value?.value?.format?.bookmark_cover,
            display_source: block.value?.value?.format?.display_source,
        };
    });
    const format = vue.computed(() => block.value?.value.format);
    const properties = vue.computed(() => block.value?.value.properties);
    const icon = vue.computed(() => format.value?.page_icon);
    const width = vue.computed(() => format.value?.block_width);
    const title = vue.computed(() => properties.value?.title);
    const caption = vue.computed(() => properties.value?.caption);
    const description = vue.computed(() => properties.value?.description);
    const type = vue.computed(() => {
        return block.value?.value.type;
    });
    const visible = vue.computed(() => {
        return type.value ? !props.hideList?.includes(type.value) : false;
    });
    const hasPageLinkOptions = vue.computed(() => {
        return props.pageLinkOptions?.component && props.pageLinkOptions?.href;
    });
    const parent = vue.computed(() => {
        return props.blockMap[block.value?.value.parent_id];
    });
    const isType = (t) => {
        if (Array.isArray(t)) {
            return visible.value && t.includes(type.value);
        }
        return visible.value && type.value === t;
    };
    const blockColorClass = (suffix = "") => {
        const blockColor = block.value?.value?.format?.block_color;
        return blockColor ? `notion-${blockColor}${suffix}` : undefined;
    };
    const pageLinkProps = (id) => {
        return props.pageLinkOptions
            ? {
                [props.pageLinkOptions.href]: props.mapPageUrl(id),
            }
            : {};
    };
    return {
        props,
        block,
        pass,
        f,
        format,
        properties,
        icon,
        width,
        title,
        caption,
        description,
        type,
        visible,
        hasPageLinkOptions,
        parent,
        isType,
        blockColorClass,
        pageLinkProps,
    };
};const availableType = [
    "page",
    "header",
    "sub_header",
    "sub_sub_header",
    "bookmark",
    "callout",
    "code",
    "equation",
    "text",
    "quote",
    "to_do",
    "toggle",
    "column_list",
    "column",
    "bulleted_list",
    "numbered_list",
    "image",
    "embed",
    "figma",
    "video",
    "audio",
    "table",
    "table_row",
    "divider",
    "table_of_contents",
];const _hoisted_1$m = ["innerHTML"];
const __default__$n = {
    name: "Katex",
};
var script$q = /*#__PURE__*/ vue.defineComponent({
    ...__default__$n,
    props: {
        expression: {
            type: String,
            required: true,
        },
    },
    setup(__props) {
        const props = __props;
        const html = vue.computed(() => katex__default["default"].renderToString(props.expression));
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("span", { innerHTML: vue.unref(html) }, null, 8 /* PROPS */, _hoisted_1$m));
        };
    }
});script$q.__file = "src/blocks/helpers/katex.vue";const _hoisted_1$l = ["target", "href"];
const _hoisted_2$f = ["target", "href"];
const _hoisted_3$5 = ["target", "href"];
const _hoisted_4$2 = { key: 5 };
const _hoisted_5$2 = {
    key: 7,
    class: "notion-inline-code"
};
const _hoisted_6$2 = { key: 8 };
const _hoisted_7$2 = { key: 9 };
const _hoisted_8$2 = { key: 10 };
const _hoisted_9 = {
    key: 11,
    class: "notion-underline"
};
const _hoisted_10 = {
    key: 13,
    class: "notion-inline-code"
};
const __default__$m = {
    name: "NotionDecorator",
};
var script$p = /*#__PURE__*/ vue.defineComponent({
    ...__default__$m,
    props: {
        content: Object,
        ...defineNotionProps,
    },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { props: blockProps, pass, type, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const text = vue.computed(() => props.content?.[0]);
        const decorators = vue.computed(() => props.content?.[1] || []);
        const decoratorKey = vue.computed(() => decorators.value?.[0]?.[0]);
        const decoratorValue = vue.computed(() => decorators.value?.[0]?.[1]);
        const unappliedDecorators = vue.computed(() => {
            const clonedDecorators = JSON.parse(JSON.stringify(decorators.value || []));
            clonedDecorators.shift(); // remove applied decorator
            return clonedDecorators;
        });
        const nextContent = vue.computed(() => [text.value, unappliedDecorators.value]);
        const isPageLink = vue.computed(() => text.value === "‣");
        const isInlinePageLink = vue.computed(() => decoratorValue.value?.[0] === "/");
        const pageLinkTitle = vue.computed(() => blockProps.blockMap?.[decoratorValue.value]?.value?.properties?.title?.[0]?.[0] || "link");
        const target = vue.computed(() => {
            if (type.value === "page") {
                return blockProps.pageLinkTarget;
            }
            return blockProps.textLinkTarget;
        });
        return (_ctx, _cache) => {
            const _component_NotionDecorator = vue.resolveComponent("NotionDecorator");
            return (vue.unref(isPageLink) && vue.unref(hasPageLinkOptions))
                ? (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(vue.unref(blockProps).pageLinkOptions?.component), vue.mergeProps({
                    key: 0,
                    class: "notion-link"
                }, vue.unref(pageLinkProps)(vue.unref(decoratorValue))), {
                    default: vue.withCtx(() => [
                        vue.createTextVNode(vue.toDisplayString(vue.unref(pageLinkTitle)), 1 /* TEXT */)
                    ]),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : (vue.unref(isPageLink))
                    ? (vue.openBlock(), vue.createElementBlock("a", {
                        key: 1,
                        class: "notion-link",
                        target: vue.unref(blockProps).pageLinkTarget,
                        href: vue.unref(blockProps).mapPageUrl(vue.unref(decoratorValue))
                    }, vue.toDisplayString(vue.unref(pageLinkTitle)), 9 /* TEXT, PROPS */, _hoisted_1$l))
                    : (vue.unref(decoratorKey) === 'a' && vue.unref(hasPageLinkOptions) && vue.unref(isInlinePageLink))
                        ? (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(vue.unref(blockProps).pageLinkOptions?.component), vue.mergeProps({
                            key: 2,
                            class: "notion-link"
                        }, vue.unref(pageLinkProps)(vue.unref(decoratorValue).slice(1))), {
                            default: vue.withCtx(() => [
                                vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ]),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (vue.unref(decoratorKey) === 'a' && vue.unref(isInlinePageLink))
                            ? (vue.openBlock(), vue.createElementBlock("a", {
                                key: 3,
                                class: "notion-link",
                                target: vue.unref(target),
                                href: vue.unref(blockProps).mapPageUrl(vue.unref(decoratorValue).slice(1))
                            }, [
                                vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ], 8 /* PROPS */, _hoisted_2$f))
                            : (vue.unref(decoratorKey) === 'a')
                                ? (vue.openBlock(), vue.createElementBlock("a", {
                                    key: 4,
                                    class: "notion-link",
                                    target: vue.unref(target),
                                    href: vue.unref(decoratorValue)
                                }, [
                                    vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                ], 8 /* PROPS */, _hoisted_3$5))
                                : (vue.unref(decorators).length === 0)
                                    ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_4$2, vue.toDisplayString(vue.unref(text)), 1 /* TEXT */))
                                    : (vue.unref(decoratorKey) === 'h')
                                        ? (vue.openBlock(), vue.createElementBlock("span", {
                                            key: 6,
                                            class: vue.normalizeClass('notion-' + vue.unref(decoratorValue))
                                        }, [
                                            vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                        ], 2 /* CLASS */))
                                        : (vue.unref(decoratorKey) === 'c')
                                            ? (vue.openBlock(), vue.createElementBlock("code", _hoisted_5$2, [
                                                vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                            ]))
                                            : (vue.unref(decoratorKey) === 'b')
                                                ? (vue.openBlock(), vue.createElementBlock("b", _hoisted_6$2, [
                                                    vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                ]))
                                                : (vue.unref(decoratorKey) === 'i')
                                                    ? (vue.openBlock(), vue.createElementBlock("em", _hoisted_7$2, [
                                                        vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                    ]))
                                                    : (vue.unref(decoratorKey) === 's')
                                                        ? (vue.openBlock(), vue.createElementBlock("s", _hoisted_8$2, [
                                                            vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                        ]))
                                                        : (vue.unref(decoratorKey) === '_')
                                                            ? (vue.openBlock(), vue.createElementBlock("u", _hoisted_9, [
                                                                vue.createVNode(_component_NotionDecorator, vue.mergeProps({ content: vue.unref(nextContent) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                            ]))
                                                            : (vue.unref(decoratorKey) === 'e' && vue.unref(blockProps).katex)
                                                                ? (vue.openBlock(), vue.createBlock(script$q, {
                                                                    key: 12,
                                                                    expression: vue.unref(decoratorValue)
                                                                }, null, 8 /* PROPS */, ["expression"]))
                                                                : (vue.unref(decoratorKey) === 'e')
                                                                    ? (vue.openBlock(), vue.createElementBlock("code", _hoisted_10, vue.toDisplayString(vue.unref(decoratorValue)), 1 /* TEXT */))
                                                                    : (vue.openBlock(), vue.createBlock(_component_NotionDecorator, vue.mergeProps({
                                                                        key: 14,
                                                                        content: vue.unref(nextContent)
                                                                    }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
        };
    }
});script$p.__file = "src/blocks/decorator.vue";const __default__$l = {
    name: "NotionTextRenderer",
};
var script$o = /*#__PURE__*/ vue.defineComponent({
    ...__default__$l,
    props: { text: Object, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, format } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("span", null, [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.text, (t, i) => {
                    return (vue.openBlock(), vue.createBlock(script$p, vue.mergeProps({
                        key: i,
                        content: t
                    }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    }
});script$o.__file = "src/blocks/helpers/text-renderer.vue";const _hoisted_1$k = { class: "notion-row" };
const _hoisted_2$e = ["href"];
const _hoisted_3$4 = { class: "notion-bookmark-title" };
const _hoisted_4$1 = {
    key: 0,
    class: "notion-bookmark-description"
};
const _hoisted_5$1 = { class: "notion-bookmark-link" };
const _hoisted_6$1 = ["alt", "src"];
const _hoisted_7$1 = {
    key: 0,
    class: "notion-bookmark-image"
};
const _hoisted_8$1 = ["alt", "src"];
const __default__$k = {
    name: "NotionBookmark",
};
var script$n = /*#__PURE__*/ vue.defineComponent({
    ...__default__$k,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { f, properties, title, description, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$k, [
                vue.createElementVNode("a", {
                    target: "_blank",
                    rel: "noopener noreferrer",
                    class: vue.normalizeClass(['notion-bookmark', vue.unref(f).block_color && `notion-${vue.unref(f).block_color}`]),
                    href: vue.unref(properties).link[0][0]
                }, [
                    vue.createElementVNode("div", null, [
                        vue.createElementVNode("div", _hoisted_3$4, [
                            vue.createVNode(script$o, vue.mergeProps({
                                text: vue.unref(title) || vue.unref(properties).link
                            }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (vue.unref(description))
                            ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_4$1, [
                                vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(description) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ]))
                            : vue.createCommentVNode("v-if", true),
                        vue.createElementVNode("div", _hoisted_5$1, [
                            (vue.unref(f).bookmark_icon)
                                ? (vue.openBlock(), vue.createElementBlock("img", {
                                    key: 0,
                                    alt: vue.unref(getTextContent)(vue.unref(title) || vue.unref(properties).link),
                                    src: vue.unref(f).bookmark_icon
                                }, null, 8 /* PROPS */, _hoisted_6$1))
                                : vue.createCommentVNode("v-if", true),
                            vue.createElementVNode("div", null, [
                                vue.createVNode(script$o, vue.mergeProps({
                                    text: vue.unref(properties).link
                                }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ])
                    ]),
                    (vue.unref(f).bookmark_cover)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_7$1, [
                            vue.createElementVNode("img", {
                                alt: vue.unref(getTextContent)(vue.unref(title) || vue.unref(properties).link),
                                src: vue.unref(f).bookmark_cover
                            }, null, 8 /* PROPS */, _hoisted_8$1)
                        ]))
                        : vue.createCommentVNode("v-if", true)
                ], 10 /* CLASS, PROPS */, _hoisted_2$e)
            ]));
        };
    }
});script$n.__file = "src/blocks/bookmark.vue";const _hoisted_1$j = ["src", "alt"];
const _hoisted_2$d = ["aria-label"];
const __default__$j = {
    name: "NotionPageIcon",
};
var script$m = /*#__PURE__*/ vue.defineComponent({
    ...__default__$j,
    props: { big: Boolean, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { icon, format, block, title } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.unref(icon)?.includes('http'))
                ? (vue.openBlock(), vue.createElementBlock("img", {
                    key: 0,
                    class: vue.normalizeClass([vue.unref(format).page_cover && 'notion-page-icon-offset', __props.big ? 'notion-page-icon-cover' : 'notion-page-icon']),
                    src: props.mapImageUrl(vue.unref(icon), vue.unref(block)),
                    alt: vue.unref(title) ? vue.unref(getTextContent)(vue.unref(title)) : 'Icon'
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$j))
                : (vue.unref(icon))
                    ? (vue.openBlock(), vue.createElementBlock("span", {
                        key: 1,
                        role: "img",
                        "aria-label": vue.unref(icon),
                        class: vue.normalizeClass([
                            'notion-emoji',
                            vue.unref(format).page_cover && 'notion-page-icon-offset',
                            __props.big ? 'notion-page-icon-cover' : 'notion-page-icon',
                        ])
                    }, vue.toDisplayString(vue.unref(icon)), 11 /* TEXT, CLASS, PROPS */, _hoisted_2$d))
                    : vue.createCommentVNode("v-if", true);
        };
    }
});script$m.__file = "src/blocks/helpers/page-icon.vue";const _hoisted_1$i = { style: { "font-size": "12px" } };
const _hoisted_2$c = { class: "notion-callout-text" };
const __default__$i = {
    name: "NotionCallout",
};
var script$l = /*#__PURE__*/ vue.defineComponent({
    ...__default__$i,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, title, blockColorClass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", {
                class: vue.normalizeClass(['notion-callout', vue.unref(blockColorClass)()])
            }, [
                vue.createElementVNode("div", _hoisted_1$i, [
                    vue.createVNode(script$m, vue.normalizeProps(vue.guardReactiveProps(vue.unref(pass))), null, 16 /* FULL_PROPS */)
                ]),
                vue.createElementVNode("div", _hoisted_2$c, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ])
            ], 2 /* CLASS */));
        };
    }
});script$l.__file = "src/blocks/callout.vue";const _hoisted_1$h = ["innerHTML"];
const _hoisted_2$b = ["innerHTML"];
var script$k = /*#__PURE__*/ vue.defineComponent({
    props: {
        code: {
            type: String,
        },
        inline: {
            type: Boolean,
            default: false,
        },
        language: {
            type: String,
            default: "markup",
        },
    },
    setup(__props) {
        const props = __props;
        const slots = vue.useSlots();
        const { inline, language } = vue.toRefs(props);
        const className = vue.computed(() => `language-${language.value}`);
        const defaultSlot = (slots && slots.default && slots.default()) || [];
        const code = props.code || (defaultSlot && defaultSlot.length && defaultSlot[0]?.children)
            ? defaultSlot[0].children
            : "";
        const d = vue.computed(() => Prism__default["default"]?.highlight(code, Prism__default["default"]?.languages[language.value], "en"));
        return (_ctx, _cache) => {
            return (vue.unref(inline))
                ? (vue.openBlock(), vue.createElementBlock("code", {
                    key: 0,
                    class: vue.normalizeClass(vue.unref(className)),
                    innerHTML: vue.unref(d)
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$h))
                : (vue.openBlock(), vue.createElementBlock("pre", {
                    key: 1,
                    class: vue.normalizeClass(vue.unref(className))
                }, [
                    vue.createElementVNode("code", { innerHTML: vue.unref(d) }, null, 8 /* PROPS */, _hoisted_2$b)
                ], 2 /* CLASS */));
        };
    }
});script$k.__file = "src/blocks/helpers/prism.vue";const _hoisted_1$g = {
    key: 0,
    class: /*#__PURE__*/ vue.normalizeClass(['notion-code'])
};
const _hoisted_2$a = {
    key: 1,
    class: /*#__PURE__*/ vue.normalizeClass(['notion-code'])
};
const __default__$h = {
    name: "NotionCode",
};
var script$j = /*#__PURE__*/ vue.defineComponent({
    ...__default__$h,
    props: { overrideLang: String, overrideLangClass: String, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties } = useNotionBlock(props);
        const lang = vue.computed(() => {
            return props.overrideLang || properties.value?.language?.[0]?.[0]?.toLowerCase();
        });
        const langClass = vue.computed(() => {
            return props.overrideLangClass || `language-${lang.value}`;
        });
        const supported = vue.computed(() => {
            return lang.value ? Prism__default["default"]?.languages[lang.value] : false;
        });
        return (_ctx, _cache) => {
            return (vue.unref(supported))
                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$g, [
                    vue.createVNode(script$k, { language: vue.unref(lang) }, {
                        default: vue.withCtx(() => [
                            vue.createTextVNode(vue.toDisplayString(vue.unref(properties)?.title[0][0]), 1 /* TEXT */)
                        ]),
                        _: 1 /* STABLE */
                    }, 8 /* PROPS */, ["language"])
                ]))
                : (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$a, [
                    vue.createElementVNode("pre", null, [
                        vue.createElementVNode("code", {
                            class: vue.normalizeClass(vue.unref(langClass))
                        }, vue.toDisplayString(vue.unref(properties)?.title[0][0]), 3 /* TEXT, CLASS */)
                    ])
                ]));
        };
    }
});script$j.__file = "src/blocks/code.vue";const __default__$g = {
    name: "NotionColumn",
};
var script$i = /*#__PURE__*/ vue.defineComponent({
    ...__default__$g,
    props: {
        format: { type: Object, required: true },
    },
    setup(__props) {
        const props = __props;
        const baseWidth = 46; // todo: add magic numbers to a config json
        const columnStyle = vue.computed(() => {
            const columns = Number((1 / props.format.column_ratio).toFixed(0));
            const totalWidth = (columns - 1) * baseWidth;
            return {
                width: `calc((100% - ${totalWidth}px) * ${props.format.column_ratio})`,
            };
        });
        const spacerStyle = vue.computed(() => ({ width: `${baseWidth}px` }));
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createBlock(vue.unref(vue3.Fragment), null, {
                default: vue.withCtx(() => [
                    vue.createElementVNode("div", {
                        class: "notion-column",
                        style: vue.normalizeStyle(vue.unref(columnStyle))
                    }, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 4 /* STYLE */),
                    vue.createElementVNode("div", {
                        class: "notion-spacer",
                        style: vue.normalizeStyle(vue.unref(spacerStyle))
                    }, null, 4 /* STYLE */)
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});script$i.__file = "src/blocks/column.vue";const _hoisted_1$f = { key: 0 };
const __default__$f = {
    name: "NotionEquation",
};
var script$h = /*#__PURE__*/ vue.defineComponent({
    ...__default__$f,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, pass } = useNotionBlock(props);
        const equation = vue.computed(() => properties.value.title?.[0]?.[0]);
        return (_ctx, _cache) => {
            return (props.katex)
                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$f, [
                    vue.createVNode(script$q, { expression: vue.unref(equation) }, null, 8 /* PROPS */, ["expression"])
                ]))
                : (vue.openBlock(), vue.createBlock(script$j, vue.mergeProps({ key: 1 }, vue.unref(pass), {
                    overrideLang: "latex",
                    overrideLangClass: "language-latex"
                }), null, 16 /* FULL_PROPS */));
        };
    }
});script$h.__file = "src/blocks/equation.vue";const _hoisted_1$e = ["src", "allow"];
const __default__$e = {
    name: "NotionAsset",
};
var script$g = /*#__PURE__*/ vue.defineComponent({
    ...__default__$e,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { type, properties, f } = useNotionBlock(props);
        const src = vue.computed(() => {
            return type.value === "figma" ? properties.value?.source[0][0] : f.value.display_source;
        });
        const style = vue.computed(() => {
            const aspectRatio = f.value.block_aspect_ratio || f.value.block_height / f.value.block_width;
            return {
                paddingBottom: `${aspectRatio * 100}%`,
                position: "relative",
            };
        });
        return (_ctx, _cache) => {
            return (vue.unref(src))
                ? (vue.openBlock(), vue.createElementBlock("div", {
                    key: 0,
                    style: vue.normalizeStyle(vue.unref(style))
                }, [
                    vue.createElementVNode("iframe", {
                        class: "notion-image-inset",
                        style: { "width": "100%" },
                        src: vue.unref(src),
                        allow: props.embedAllow
                    }, null, 8 /* PROPS */, _hoisted_1$e)
                ], 4 /* STYLE */))
                : vue.createCommentVNode("v-if", true);
        };
    }
});script$g.__file = "src/blocks/helpers/asset.vue";const _hoisted_1$d = ["alt", "src"];
const _hoisted_2$9 = ["alt", "src"];
const __default__$d = {
    name: "NotionImage",
};
var script$f = /*#__PURE__*/ vue.defineComponent({
    ...__default__$d,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { caption, properties, block, f } = useNotionBlock(props);
        const alt = vue.computed(() => {
            return caption?.value?.[0][0];
        });
        const src = vue.computed(() => {
            return props.mapImageUrl(properties.value?.source[0][0], block.value);
        });
        const aspectRatioStyle = vue.computed(() => {
            let aspectRatio = f.value.block_width == 1 || f.value.block_height == 1
                ? 1 / f.value.block_aspect_ratio
                : `${f.value.block_width} / ${f.value.block_height} `;
            return {
                width: `${f.value.block_width}px`,
                height: `100%`,
                maxWidth: "100%",
                position: "relative",
                aspectRatio,
            };
        });
        const basicStyle = vue.computed(() => {
            return {
                width: f.value.block_width == 1 ? "100%" : `${f.value.block_width}px`,
                height: f.value.block_height == 1 ? "100%" : `${f.value.block_height}px`,
            };
        });
        return (_ctx, _cache) => {
            return (vue.unref(f).block_aspect_ratio)
                ? (vue.openBlock(), vue.createElementBlock("div", {
                    key: 0,
                    style: vue.normalizeStyle(vue.unref(aspectRatioStyle))
                }, [
                    vue.createElementVNode("img", {
                        class: "notion-image-inset",
                        alt: vue.unref(alt) || 'Notion image',
                        src: vue.unref(src)
                    }, null, 8 /* PROPS */, _hoisted_1$d)
                ], 4 /* STYLE */))
                : (vue.openBlock(), vue.createElementBlock("img", {
                    key: 1,
                    alt: vue.unref(alt),
                    src: vue.unref(src),
                    style: vue.normalizeStyle(vue.unref(basicStyle))
                }, null, 12 /* STYLE, PROPS */, _hoisted_2$9));
        };
    }
});script$f.__file = "src/blocks/helpers/image.vue";const _hoisted_1$c = {
    key: 2,
    class: "notion-image-caption"
};
const __default__$c = {
    name: "NotionFigure",
};
var script$e = /*#__PURE__*/ vue.defineComponent({
    ...__default__$c,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, width, caption, isType } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("figure", {
                class: "notion-asset-wrapper",
                style: vue.normalizeStyle(vue.unref(width))
            }, [
                (vue.unref(isType)('image'))
                    ? (vue.openBlock(), vue.createBlock(script$f, vue.normalizeProps(vue.mergeProps({ key: 0 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                    : (vue.unref(isType)(['embed', 'video', 'figma']))
                        ? (vue.openBlock(), vue.createBlock(script$g, vue.normalizeProps(vue.mergeProps({ key: 1 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                        : vue.createCommentVNode("v-if", true),
                (vue.unref(caption))
                    ? (vue.openBlock(), vue.createElementBlock("figcaption", _hoisted_1$c, [
                        vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(caption) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]))
                    : vue.createCommentVNode("v-if", true)
            ], 4 /* STYLE */));
        };
    }
});script$e.__file = "src/blocks/helpers/figure.vue";const _hoisted_1$b = ["id"];
const _hoisted_2$8 = ["id"];
const _hoisted_3$3 = ["id"];
const __default__$b = {
    name: "NotionHeader",
};
var script$d = /*#__PURE__*/ vue.defineComponent({
    ...__default__$b,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { type, title, pass, block } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.unref(type) === 'header')
                ? (vue.openBlock(), vue.createElementBlock("h1", {
                    key: 0,
                    class: "notion-h1",
                    id: vue.unref(block).value.id
                }, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 8 /* PROPS */, _hoisted_1$b))
                : (vue.unref(type) === 'sub_header')
                    ? (vue.openBlock(), vue.createElementBlock("h2", {
                        key: 1,
                        class: "notion-h2",
                        id: vue.unref(block).value.id
                    }, [
                        vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ], 8 /* PROPS */, _hoisted_2$8))
                    : (vue.unref(type) === 'sub_sub_header')
                        ? (vue.openBlock(), vue.createElementBlock("h3", {
                            key: 2,
                            class: "notion-h3",
                            id: vue.unref(block).value.id
                        }, [
                            vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ], 8 /* PROPS */, _hoisted_3$3))
                        : vue.createCommentVNode("v-if", true);
        };
    }
});script$d.__file = "src/blocks/header.vue";const _hoisted_1$a = {
    key: 0,
    class: "notion-list notion-list-disc"
};
const _hoisted_2$7 = {
    key: 1,
    class: "notion-list notion-list-numbered"
};
const __default__$a = {
    name: "NotionNestedList",
};
var script$c = /*#__PURE__*/ vue.defineComponent({
    ...__default__$a,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, type } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.unref(type) === 'bulleted_list')
                ? (vue.openBlock(), vue.createElementBlock("ul", _hoisted_1$a, [
                    vue.renderSlot(_ctx.$slots, "default")
                ]))
                : (vue.openBlock(), vue.createElementBlock("ol", _hoisted_2$7, [
                    vue.renderSlot(_ctx.$slots, "default")
                ]));
        };
    }
});script$c.__file = "src/blocks/helpers/nested-list.vue";const _hoisted_1$9 = {
    key: 0,
    class: "notion-list notion-list-disc"
};
const _hoisted_2$6 = ["start"];
const _hoisted_3$2 = { key: 2 };
const __default__$9 = {
    name: "NotionList",
};
var script$b = /*#__PURE__*/ vue.defineComponent({
    ...__default__$9,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, type, title, pass } = useNotionBlock(props);
        const start = vue.computed(() => {
            return props.blockMap
                ? block.value?.value?.format?.list_start_index || getListNumber(block.value.value.id, props.blockMap)
                : 0;
        });
        const isTopLevel = vue.computed(() => type.value != props.blockMap?.[block.value.value.parent_id].value.type);
        return (_ctx, _cache) => {
            return (vue.unref(isTopLevel) && vue.unref(type) === 'bulleted_list')
                ? (vue.openBlock(), vue.createElementBlock("ul", _hoisted_1$9, [
                    vue.createElementVNode("li", null, [
                        vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]),
                    (vue.unref(block).value.content)
                        ? (vue.openBlock(), vue.createBlock(script$c, vue.normalizeProps(vue.mergeProps({ key: 0 }, vue.unref(pass))), {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        }, 16 /* FULL_PROPS */))
                        : vue.createCommentVNode("v-if", true)
                ]))
                : (vue.unref(isTopLevel) && vue.unref(type) === 'numbered_list')
                    ? (vue.openBlock(), vue.createElementBlock("ol", {
                        key: 1,
                        class: "notion-list notion-list-numbered",
                        start: vue.unref(start)
                    }, [
                        vue.createElementVNode("li", null, [
                            vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (vue.unref(block).value.content)
                            ? (vue.openBlock(), vue.createBlock(script$c, vue.mergeProps({
                                key: 0,
                                class: [_ctx.level == 1 ? 'notion-list-flat' : '']
                            }, vue.unref(pass)), {
                                default: vue.withCtx(() => [
                                    vue.renderSlot(_ctx.$slots, "default")
                                ]),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */, ["class"]))
                            : vue.createCommentVNode("v-if", true)
                    ], 8 /* PROPS */, _hoisted_2$6))
                    : (vue.openBlock(), vue.createElementBlock("span", _hoisted_3$2, [
                        vue.createElementVNode("li", {
                            class: vue.normalizeClass([_ctx.level != 1 ? 'notion-list-indent' : ''])
                        }, [
                            vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ], 2 /* CLASS */),
                        (vue.unref(block).value.content)
                            ? (vue.openBlock(), vue.createBlock(script$c, vue.normalizeProps(vue.mergeProps({ key: 0 }, vue.unref(pass))), {
                                default: vue.withCtx(() => [
                                    vue.renderSlot(_ctx.$slots, "default")
                                ]),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */))
                            : vue.createCommentVNode("v-if", true)
                    ]));
        };
    }
});script$b.__file = "src/blocks/list.vue";const _hoisted_1$8 = ["alt", "src"];
const _hoisted_2$5 = { class: "notion-title" };
const _hoisted_3$1 = {
    key: 1,
    class: "notion"
};
const _hoisted_4 = { class: "notion-page-icon" };
const _hoisted_5 = { class: "notion-page-text" };
const _hoisted_6 = ["target", "href"];
const _hoisted_7 = { class: "notion-page-icon" };
const _hoisted_8 = { class: "notion-page-text" };
const __default__$8 = {
    name: "NotionPage",
};
var script$a = /*#__PURE__*/ vue.defineComponent({
    ...__default__$8,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { format, title, block, pass, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const coverStyle = vue.computed(() => {
            const coverPosition = (1 - (format.value.page_cover_position || 0.5)) * 100;
            return { objectPosition: `center ${coverPosition}%` };
        });
        const computedFont = vue.computed(() => {
            let font = block.value.value.format?.page_font || "";
            if (font == "serif") {
                return { fontFamily: "Lyon-Text, Georgia, ui-serif, serif" };
            }
            else if (font == "mono") {
                return { fontFamily: "iawriter-mono, Nitti, Menlo, Courier, monospace" };
            }
        });
        return (_ctx, _cache) => {
            return (props.level === 0 && props.fullPage)
                ? (vue.openBlock(), vue.createElementBlock("div", {
                    key: 0,
                    class: "notion",
                    style: vue.normalizeStyle(vue.unref(computedFont))
                }, [
                    vue.createCommentVNode(" todo: add header "),
                    vue.createCommentVNode(" <NotionPageHeader v-if=\"!hideHeader\" v-bind=\"pass\" /> "),
                    vue.createCommentVNode(" todo: hide image if no .format is available "),
                    (vue.unref(format) && vue.unref(format).page_cover)
                        ? (vue.openBlock(), vue.createElementBlock("img", {
                            key: 0,
                            class: "notion-page-cover",
                            style: vue.normalizeStyle(vue.unref(coverStyle)),
                            alt: vue.unref(getTextContent)(vue.unref(title)),
                            src: props.mapImageUrl(vue.unref(format).page_cover, vue.unref(block))
                        }, null, 12 /* STYLE, PROPS */, _hoisted_1$8))
                        : vue.createCommentVNode("v-if", true),
                    vue.createElementVNode("main", {
                        class: vue.normalizeClass([
                            'notion-page',
                            vue.unref(format) && !vue.unref(format).page_cover && 'notion-page-offset',
                            vue.unref(format) && vue.unref(format).page_full_width && 'notion-full-width',
                            vue.unref(format) && vue.unref(format).page_small_text && 'notion-small-text',
                        ])
                    }, [
                        vue.createVNode(script$m, vue.mergeProps(vue.unref(pass), { big: "" }), null, 16 /* FULL_PROPS */),
                        vue.createElementVNode("div", _hoisted_2$5, [
                            vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ], 4 /* STYLE */))
                : (props.level === 0)
                    ? (vue.openBlock(), vue.createElementBlock("main", _hoisted_3$1, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]))
                    : (vue.unref(hasPageLinkOptions))
                        ? (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(props.pageLinkOptions?.component), vue.mergeProps({
                            key: 2,
                            class: "notion-page-link"
                        }, vue.unref(pageLinkProps)(vue.unref(block).value.id)), {
                            default: vue.withCtx(() => [
                                vue.createElementVNode("div", _hoisted_4, [
                                    vue.createVNode(script$m, vue.normalizeProps(vue.guardReactiveProps(vue.unref(pass))), null, 16 /* FULL_PROPS */)
                                ]),
                                vue.createElementVNode("div", _hoisted_5, [
                                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                                ])
                            ]),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (vue.openBlock(), vue.createElementBlock("a", {
                            key: 3,
                            class: "notion-page-link",
                            target: props.pageLinkTarget,
                            href: props.mapPageUrl(vue.unref(block).value.id)
                        }, [
                            vue.createElementVNode("div", _hoisted_7, [
                                vue.createVNode(script$m, vue.normalizeProps(vue.guardReactiveProps(vue.unref(pass))), null, 16 /* FULL_PROPS */)
                            ]),
                            vue.createElementVNode("div", _hoisted_8, [
                                vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 8 /* PROPS */, _hoisted_6));
        };
    }
});script$a.__file = "src/blocks/page.vue";const _hoisted_1$7 = {
    key: 0,
    class: "notion-quote"
};
const __default__$7 = {
    name: "NotionQuote",
};
var script$9 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$7,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, title, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.unref(properties))
                ? (vue.openBlock(), vue.createElementBlock("blockquote", _hoisted_1$7, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]))
                : vue.createCommentVNode("v-if", true);
        };
    }
});script$9.__file = "src/blocks/quote.vue";var script$8 = {
    name: "NotionTable",
};const _hoisted_1$6 = { class: "notion-simple-table-wrapper" };
const _hoisted_2$4 = { class: "notion-simple-table" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$6, [
    vue.createElementVNode("table", _hoisted_2$4, [
      vue.createElementVNode("tbody", null, [
        vue.renderSlot(_ctx.$slots, "default")
      ])
    ])
  ]))
}script$8.render = render;
script$8.__file = "src/blocks/table.vue";const _hoisted_1$5 = { class: "notion-simple-table-row" };
const _hoisted_2$3 = { class: "notion-simple-table-cell-text" };
const __default__$6 = {
    name: "NotionTableRow",
};
var script$7 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$6,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { parent, properties, pass } = useNotionBlock(props);
        const { table_block_column_header: hasHeaderColumn, table_block_row_header: hasHeaderRow, table_block_column_order: columns, } = parent.value.value.format;
        const cell = (columnId) => {
            return properties.value[columnId];
        };
        const isHeader = (columnIndex) => {
            return (hasHeaderColumn && props.contentIndex == 0) || (hasHeaderRow && columnIndex == 0);
        };
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("tr", _hoisted_1$5, [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(columns), (columnId, columnIndex) => {
                    return (vue.openBlock(), vue.createElementBlock("td", {
                        key: columnIndex,
                        class: "notion-simple-table-data"
                    }, [
                        vue.createElementVNode("div", {
                            class: vue.normalizeClass({ 'notion-simple-table-header': isHeader(columnIndex) })
                        }, [
                            vue.createElementVNode("div", _hoisted_2$3, [
                                vue.createVNode(script$o, vue.mergeProps({
                                    text: cell(columnId)
                                }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 2 /* CLASS */)
                    ]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    }
});script$7.__file = "src/blocks/table-row.vue";const _hoisted_1$4 = {
    key: 1,
    class: "notion-blank"
};
const __default__$5 = {
    name: "NotionText",
};
var script$6 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$5,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, title, pass, blockColorClass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.unref(properties))
                ? (vue.openBlock(), vue.createElementBlock("p", {
                    key: 0,
                    class: vue.normalizeClass(['notion-text', vue.unref(blockColorClass)()])
                }, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 2 /* CLASS */))
                : (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$4, " "));
        };
    }
});script$6.__file = "src/blocks/text.vue";const _hoisted_1$3 = { class: "notion-to-do-item" };
const _hoisted_2$2 = ["value", "checked"];
const __default__$4 = {
    name: "NotionTodo",
};
var script$5 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$4,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { title, properties, pass } = useNotionBlock(props);
        const checked = vue.computed(() => properties.value?.checked?.[0] == "Yes");
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("label", _hoisted_1$3, [
                vue.createElementVNode("input", {
                    type: "checkbox",
                    class: "notion-property-checkbox",
                    value: vue.unref(checked),
                    checked: vue.unref(checked),
                    disabled: "true"
                }, null, 8 /* PROPS */, _hoisted_2$2),
                vue.createElementVNode("label", {
                    class: vue.normalizeClass({ 'notion-to-do-checked': vue.unref(checked) })
                }, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 2 /* CLASS */)
            ]));
        };
    }
});script$5.__file = "src/blocks/todo.vue";const _hoisted_1$2 = { class: "notion-toggle" };
const __default__$3 = {
    name: "NotionToggle",
};
var script$4 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$3,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { title, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("details", _hoisted_1$2, [
                vue.createElementVNode("summary", null, [
                    vue.createVNode(script$o, vue.mergeProps({ text: vue.unref(title) }, vue.unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]),
                vue.createElementVNode("div", null, [
                    vue.renderSlot(_ctx.$slots, "default")
                ])
            ]));
        };
    }
});script$4.__file = "src/blocks/toggle.vue";const __default__$2 = {
    name: "NotionTableOfContentItem",
};
var script$3 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$2,
    props: { text: Object, level: { type: Number, default: 0 } },
    setup(__props) {
        const props = __props;
        const computedText = vue.computed(() => (props.text ? props.text.map((i) => i[0]).join("") : ""));
        const computedStyle = vue.computed(() => ({
            paddingLeft: 1.5 * props.level + "rem",
        }));
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("span", {
                class: "notion-table-of-contents-item",
                style: vue.normalizeStyle(vue.unref(computedStyle))
            }, vue.toDisplayString(vue.unref(computedText)), 5 /* TEXT, STYLE */));
        };
    }
});script$3.__file = "src/blocks/helpers/table-of-contents-item.vue";const _hoisted_1$1 = { class: "notion-table-of-contents" };
const _hoisted_2$1 = ["target", "href"];
const __default__$1 = {
    name: "NotionTableOfContent",
};
var script$2 = /*#__PURE__*/ vue.defineComponent({
    ...__default__$1,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, parent, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const headers = ["header", "sub_header", "sub_sub_header"];
        const headerObjects = vue.computed(() => {
            if (!props.blockMap)
                return;
            let temp = [];
            Object.entries(props.blockMap).forEach(([key, value]) => {
                if (headers.includes(value.value.type) && value.value.parent_id == parent.value.value.id) {
                    let level = 0;
                    if (temp.length) {
                        let prevBlock = temp[temp.length - 1];
                        if (value.value.type == "header") ;
                        else if (value.value.type == "sub_header") {
                            level = 1;
                        }
                        else if (value.value.type == prevBlock.value.type) {
                            level = prevBlock.level;
                        }
                        else if (value.value.type != prevBlock.value.type) {
                            level = prevBlock.level + 1;
                        }
                    }
                    temp.push({ ...value, level });
                }
            });
            return temp;
        });
        console.log(headerObjects);
        return (_ctx, _cache) => {
            return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$1, [
                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(headerObjects), (header) => {
                    return (vue.openBlock(), vue.createElementBlock("a", {
                        class: "notion-page-link",
                        target: props.pageLinkTarget,
                        href: `#${header.value.id}`
                    }, [
                        vue.createVNode(script$3, {
                            text: header.value.properties.title,
                            level: header.level
                        }, null, 8 /* PROPS */, ["text", "level"])
                    ], 8 /* PROPS */, _hoisted_2$1));
                }), 256 /* UNKEYED_FRAGMENT */))
            ]));
        };
    }
});script$2.__file = "src/blocks/table-of-contents.vue";const _hoisted_1 = {
    key: 0,
    style: { "width": "100%" }
};
const _hoisted_2 = {
    key: 10,
    class: "notion-row"
};
const _hoisted_3 = {
    key: 17,
    class: "notion-hr"
};
var script$1 = /*#__PURE__*/ vue.defineComponent({
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, type, format, isType } = useNotionBlock(props);
        if (!availableType.includes(type.value))
            console.warn(`${type.value.toUpperCase()} is not implemented yet`);
        // console.log(type.value)
        return (_ctx, _cache) => {
            return (vue.unref(isType)('page'))
                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_1, [
                    vue.createVNode(script$a, vue.normalizeProps(vue.guardReactiveProps(vue.unref(pass))), {
                        default: vue.withCtx(() => [
                            vue.renderSlot(_ctx.$slots, "default")
                        ]),
                        _: 3 /* FORWARDED */
                    }, 16 /* FULL_PROPS */)
                ]))
                : (vue.unref(isType)(['header', 'sub_header', 'sub_sub_header']))
                    ? (vue.openBlock(), vue.createBlock(script$d, vue.normalizeProps(vue.mergeProps({ key: 1 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                    : (vue.unref(isType)('bookmark'))
                        ? (vue.openBlock(), vue.createBlock(script$n, vue.normalizeProps(vue.mergeProps({ key: 2 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                        : (vue.unref(isType)('callout'))
                            ? (vue.openBlock(), vue.createBlock(script$l, vue.normalizeProps(vue.mergeProps({ key: 3 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                            : (vue.unref(isType)('code'))
                                ? (vue.openBlock(), vue.createBlock(script$j, vue.normalizeProps(vue.mergeProps({ key: 4 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                : (vue.unref(isType)('equation'))
                                    ? (vue.openBlock(), vue.createBlock(script$h, vue.normalizeProps(vue.mergeProps({ key: 5 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                    : (vue.unref(isType)('text'))
                                        ? (vue.openBlock(), vue.createBlock(script$6, vue.normalizeProps(vue.mergeProps({ key: 6 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                        : (vue.unref(isType)('quote'))
                                            ? (vue.openBlock(), vue.createBlock(script$9, vue.normalizeProps(vue.mergeProps({ key: 7 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                            : (vue.unref(isType)('to_do'))
                                                ? (vue.openBlock(), vue.createBlock(script$5, vue.normalizeProps(vue.mergeProps({ key: 8 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                                : (vue.unref(isType)('toggle'))
                                                    ? (vue.openBlock(), vue.createBlock(script$4, vue.normalizeProps(vue.mergeProps({ key: 9 }, vue.unref(pass))), {
                                                        default: vue.withCtx(() => [
                                                            vue.renderSlot(_ctx.$slots, "default")
                                                        ]),
                                                        _: 3 /* FORWARDED */
                                                    }, 16 /* FULL_PROPS */))
                                                    : (vue.unref(isType)('column_list'))
                                                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2, [
                                                            vue.renderSlot(_ctx.$slots, "default")
                                                        ]))
                                                        : (vue.unref(isType)('column'))
                                                            ? (vue.openBlock(), vue.createBlock(script$i, {
                                                                key: 11,
                                                                format: vue.unref(format)
                                                            }, {
                                                                default: vue.withCtx(() => [
                                                                    vue.renderSlot(_ctx.$slots, "default")
                                                                ]),
                                                                _: 3 /* FORWARDED */
                                                            }, 8 /* PROPS */, ["format"]))
                                                            : (vue.unref(isType)(['bulleted_list', 'numbered_list']))
                                                                ? (vue.openBlock(), vue.createBlock(script$b, vue.normalizeProps(vue.mergeProps({ key: 12 }, vue.unref(pass))), {
                                                                    default: vue.withCtx(() => [
                                                                        vue.renderSlot(_ctx.$slots, "default")
                                                                    ]),
                                                                    _: 3 /* FORWARDED */
                                                                }, 16 /* FULL_PROPS */))
                                                                : (vue.unref(isType)(['image', 'embed', 'figma', 'video', 'audio']))
                                                                    ? (vue.openBlock(), vue.createBlock(script$e, vue.normalizeProps(vue.mergeProps({ key: 13 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                                                    : (vue.unref(isType)('table'))
                                                                        ? (vue.openBlock(), vue.createBlock(script$8, vue.normalizeProps(vue.mergeProps({ key: 14 }, vue.unref(pass))), {
                                                                            default: vue.withCtx(() => [
                                                                                vue.renderSlot(_ctx.$slots, "default")
                                                                            ]),
                                                                            _: 3 /* FORWARDED */
                                                                        }, 16 /* FULL_PROPS */))
                                                                        : (vue.unref(isType)('table_row'))
                                                                            ? (vue.openBlock(), vue.createBlock(script$7, vue.normalizeProps(vue.mergeProps({ key: 15 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                                                            : (vue.unref(isType)('table_of_contents'))
                                                                                ? (vue.openBlock(), vue.createBlock(script$2, vue.normalizeProps(vue.mergeProps({ key: 16 }, vue.unref(pass))), null, 16 /* FULL_PROPS */))
                                                                                : (vue.unref(isType)('divider'))
                                                                                    ? (vue.openBlock(), vue.createElementBlock("hr", _hoisted_3))
                                                                                    : vue.createCommentVNode("v-if", true);
        };
    }
});script$1.__file = "src/components/block.vue";const __default__ = {
    name: "NotionRenderer",
};
var script = /*#__PURE__*/ vue.defineComponent({
    ...__default__,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, block } = useNotionBlock(props);
        return (_ctx, _cache) => {
            const _component_NotionRenderer = vue.resolveComponent("NotionRenderer", true);
            return (vue.unref(block))
                ? (vue.openBlock(), vue.createBlock(script$1, vue.normalizeProps(vue.mergeProps({ key: 0 }, vue.unref(pass))), {
                    default: vue.withCtx(() => [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(block).value.content, (contentId, contentIndex) => {
                            return (vue.openBlock(), vue.createBlock(_component_NotionRenderer, vue.mergeProps(vue.unref(pass), {
                                key: contentId,
                                level: vue.unref(pass).level + 1,
                                "content-id": contentId,
                                "content-index": contentIndex
                            }), null, 16 /* FULL_PROPS */, ["level", "content-id", "content-index"]));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : vue.createCommentVNode("v-if", true);
        };
    }
});script.__file = "src/components/notion-renderer.vue";var components=/*#__PURE__*/Object.freeze({__proto__:null,NotionRenderer:script});const getPageTable = async (pageId, apiUrl = "https://api.vue-notion.workers.dev/v1") => await fetch(`${apiUrl}/table/${pageId}`)
    .then((res) => res.json())
    .then((data) => data)
    .catch((err) => err);
const getPageBlocks = async (pageId, apiUrl = "https://api.vue-notion.workers.dev/v1") => await fetch(`${apiUrl}/page/${pageId}`)
    .then((res) => res.json())
    .then((data) => data)
    .catch((err) => err);exports.Role=void 0;
(function (Role) {
    Role["Reader"] = "reader";
})(exports.Role || (exports.Role = {}));const useGetPageBlocks = (...arg) => {
    const data = vue.ref();
    vue.onMounted(async () => {
        data.value = await getPageBlocks(...arg);
    });
    return {
        data,
    };
};
const useGetPageTable = (...arg) => {
    const data = vue.ref();
    vue.onMounted(async () => {
        data.value = await getPageTable(...arg);
    });
    return {
        data,
    };
};// Default export is library as a whole, registered via Vue.use()
var index = {
    install: (app) => {
        Object.entries(components).forEach(([componentName, component]) => {
            app.component(componentName, component);
        });
    },
};exports.NotionRenderer=script;exports["default"]=index;exports.getPageBlocks=getPageBlocks;exports.getPageTable=getPageTable;exports.useGetPageBlocks=useGetPageBlocks;exports.useGetPageTable=useGetPageTable;Object.defineProperty(exports,'__esModule',{value:true});return exports;})({},Vue,katex,Prism,Fragment);